sphinx-themes
=============

These are some themes for Python `Sphinx <http://sphinx.pocoo.org/>`_
documentation projects.

Preview
-------
To see how these themes look, visit http://vimalkumar.in/sphinx-themes

Download
--------
Released versions are available from https://github.com/vkvn/sphinx-themes/downloads

You can also download this repository as a `zip archive <https://github.com/vkvn/sphinx-themes/zipball/master>`_

Support
-------
If there are problems with any of these themes, you can file a bug report at
https://github.com/vkvn/sphinx-themes/issues

Themes are licensed under the
`GNU General Public License <http://www.gnu.org/licenses/gpl.html>`_.


.. raw:: html

   <iframe style="border: 0; margin: 0; padding: 0;"
           src="https://www.gittip.com/vkvn/widget.html"
           width="48pt" height="22pt"></iframe>

   <a href="http://coderwall.com/vkvn"><img alt="Endorse vkvn on Coderwall" src="http://api.coderwall.com/vkvn/endorsecount.png" /></a>
